The Grading Layer
=================

Contents:

.. toctree::
   :maxdepth: 2

   grading-manager
   grader-interface
   prompt-grader
   open-file-grader
   junit-grader
   lc3test-grader
   libcheck-grader
   docker-wrapper-grader
